@@ -8,17 +8,17 @@
 """
 
 from os import path
-import directives
+from sphinxjp.themes.revealjs import directives
 
 package_dir = path.abspath(path.dirname(__file__))
 template_path = path.join(package_dir, 'templates')
 
 
 def get_path():
-    """entry-point for sphinxjp.themecore theme."""
+    """entry-point for sphinx  theme."""
     return template_path
 
 
-def setup_directives(app):
-    """entry-point for sphinxjp.themecore directive."""
+def setup(app):
+    """entry-point for sphinx  directive."""
     directives.setup(app)
